about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/hppa/bits
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>2003-03-03 10:05:49 +0000
committerUlrich Drepper <drepper@redhat.com>2003-03-03 10:05:49 +0000
commitd15a8404ef0c8d928998b7bab64c7b2bb9e2dcf7 (patch)
treea6833870beda8ea25d88c4036460834cc3925b13 /sysdeps/unix/sysv/linux/hppa/bits
parent0ddc17ba4b91327a46f69cd206c8959d09a96fe7 (diff)
downloadglibc-d15a8404ef0c8d928998b7bab64c7b2bb9e2dcf7.tar.gz
glibc-d15a8404ef0c8d928998b7bab64c7b2bb9e2dcf7.tar.xz
glibc-d15a8404ef0c8d928998b7bab64c7b2bb9e2dcf7.zip
Update.
2003-03-03  Ulrich Drepper  <drepper@redhat.com>

	* sysdeps/unix/sysv/linux/syscalls.list: Add remap_file_pages entry.
	* misc/sys/mman.h: Add prototype for remap_file_pages.
	* sysdeps/generic/remap_file_pages.c: New file.

	* sysdeps/unix/sysv/linux/x86_64/bits/mman.h: Define MAP_POPULATE
	and MAP_NONBLOCK.
	* sysdeps/unix/sysv/linux/s390/bits/mman.h: Likewise.
	* sysdeps/unix/sysv/linux/powerpc/bits/mman.h: Likewise
	* sysdeps/unix/sysv/linux/m68k/bits/mman.h: Likewise.
	* sysdeps/unix/sysv/linux/arm/bits/mman.h: Likewise.
	* sysdeps/unix/sysv/linux/ia64/bits/mman.h: Likewise.
	* sysdeps/unix/sysv/linux/hppa/bits/mman.h: Likewise.
	* sysdeps/unix/sysv/linux/alpha/bits/mman.h: Likewise.
	* sysdeps/unix/sysv/linux/i386/bits/mman.h: Likewise.

	* sysdeps/unix/clock_settime.c (HANDLE_REALTIME): Add missing brace.
Diffstat (limited to 'sysdeps/unix/sysv/linux/hppa/bits')
-rw-r--r--sysdeps/unix/sysv/linux/hppa/bits/mman.h22
1 files changed, 20 insertions, 2 deletions
diff --git a/sysdeps/unix/sysv/linux/hppa/bits/mman.h b/sysdeps/unix/sysv/linux/hppa/bits/mman.h
index 78c0171fae..40db9f9b90 100644
--- a/sysdeps/unix/sysv/linux/hppa/bits/mman.h
+++ b/sysdeps/unix/sysv/linux/hppa/bits/mman.h
@@ -1,4 +1,21 @@
-/* Definitions for POSIX memory map interface.  Insert rest of disclaimer here */
+/* Definitions for POSIX memory map interface.  Linux/HPPA version.
+   Copyright (C) 1997, 1998, 2000, 2003 Free Software Foundation, Inc.
+   This file is part of the GNU C Library.
+
+   The GNU C Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2.1 of the License, or (at your option) any later version.
+
+   The GNU C Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with the GNU C Library; if not, write to the Free
+   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+   02111-1307 USA.  */
 
 #ifndef _SYS_MMAN_H
 # error "Never use <bits/mman.h> directly; include <sys/mman.h> instead."
@@ -22,6 +39,8 @@
 #define MAP_LOCKED	0x2000		/* pages are locked */
 #define MAP_NORESERVE	0x4000		/* don't check for reservations */
 #define MAP_GROWSDOWN	0x8000		/* stack-like segment */
+#define MAP_POPULATE	0x10000		/* populate (prefault) pagetables */
+#define MAP_NONBLOCK	0x20000		/* do not block on IO */
 
 #define MS_SYNC		1		/* synchronous memory sync */
 #define MS_ASYNC	2		/* sync memory asynchronously */
@@ -58,4 +77,3 @@
 #ifdef __USE_GNU
 # define MREMAP_MAYMOVE 1
 #endif
-